@@ -77,8 +77,6 @@ public Q_SLOTS:
     void documentNameChanged(KTextEditor::Document *);
     void documentModifiedChanged(KTextEditor::Document *);
     void documentModifiedOnDisc(KTextEditor::Document *, bool, KTextEditor::ModificationInterface::ModifiedOnDiskReason);
-    void slotAboutToDeleteDocuments(const QList<KTextEditor::Document *> &);
-    void slotDocumentsDeleted(const QList<KTextEditor::Document *> &);
 
 Q_SIGNALS:
     void triggerViewChangeAfterNameChange();
