@@ -8,6 +8,7 @@
 #define KATE_FILETREE_PLUGIN_H
 
 #include <QIcon>
+#include <QTimer>
 
 #include <KTextEditor/Command>
 #include <KTextEditor/Plugin>
@@ -45,7 +46,7 @@ public:
 
     const KateFileTreePluginSettings &settings();
 
-    void applyConfig(bool shadingEnabled, const QColor &viewShade, const QColor &editShade, bool listMode, int sortRole, bool showFulPath);
+    void applyConfig(bool shadingEnabled, const QColor &viewShade, const QColor &editShade, bool listMode, int sortRole, bool showFullPath, bool showToolbar, bool closeButton);
 
 public Q_SLOTS:
     void viewDestroyed(QObject *view);
@@ -80,21 +81,22 @@ public:
      * The file tree model.
      * @return the file tree model
      */
-    KateFileTreeModel *model();
+    KateFileTreeModel *model() const;
     /**
      * The file tree proxy model.
      * @return the file tree proxy model
      */
-    KateFileTreeProxyModel *proxy();
+    KateFileTreeProxyModel *proxy() const;
     /**
      * The file tree.
      * @return the file tree
      */
-    KateFileTree *tree();
+    KateFileTree *tree() const;
 
+    void setToolbarVisible(bool);
     void setListMode(bool listMode);
 
-    bool hasLocalPrefs();
+    bool hasLocalPrefs() const;
     void setHasLocalPrefs(bool);
 
 protected:
@@ -108,9 +110,10 @@ private:
     QLineEdit *m_filter;
     KateFileTreeModel *m_documentModel;
     bool m_hasLocalPrefs = false;
-    bool m_loadingDocuments;
     KateFileTreePlugin *m_plug;
     KTextEditor::MainWindow *m_mainWindow;
+    QTimer m_documentsCreatedTimer;
+    QList<KTextEditor::Document *> m_documentsCreated;
 
 private Q_SLOTS:
     void showToolView();
@@ -122,10 +125,9 @@ private Q_SLOTS:
     void documentClosed(KTextEditor::Document *);
     void viewModeChanged(bool);
     void sortRoleChanged(int);
-    void slotAboutToCreateDocuments();
-    void slotDocumentsCreated(const QList<KTextEditor::Document *> &);
-    void slotDocumentSave();
-    void slotDocumentSaveAs();
+    void slotDocumentsCreated();
+    void slotDocumentSave() const;
+    void slotDocumentSaveAs() const;
 };
 
 #endif // KATE_FILETREE_PLUGIN_H
