@@ -45,6 +45,8 @@
 
 K_PLUGIN_FACTORY_WITH_JSON(KateKonsolePluginFactory, "katekonsoleplugin.json", registerPlugin<KateKonsolePlugin>();)
 
+static const QStringList s_escapeExceptions{QStringLiteral("vi"), QStringLiteral("vim"), QStringLiteral("nvim")};
+
 KateKonsolePlugin::KateKonsolePlugin(QObject *parent, const QList<QVariant> &)
     : KTextEditor::Plugin(parent)
 {
@@ -54,9 +56,18 @@ KateKonsolePlugin::KateKonsolePlugin(QObject *parent, const QList<QVariant> &)
     }
 }
 
+void setEditorEnv(const QByteArray &value)
+{
+    if (value.isNull()) {
+        qunsetenv("EDITOR");
+    } else {
+        qputenv("EDITOR", value.data());
+    }
+}
+
 KateKonsolePlugin::~KateKonsolePlugin()
 {
-    qputenv("EDITOR", m_previousEditorEnv.data());
+    setEditorEnv(m_previousEditorEnv);
 }
 
 QObject *KateKonsolePlugin::createView(KTextEditor::MainWindow *mainWindow)
@@ -67,15 +78,17 @@ QObject *KateKonsolePlugin::createView(KTextEditor::MainWindow *mainWindow)
 
 KTextEditor::ConfigPage *KateKonsolePlugin::configPage(int number, QWidget *parent)
 {
-    if (number != 0)
+    if (number != 0) {
         return nullptr;
+    }
     return new KateKonsoleConfigPage(parent, this);
 }
 
 void KateKonsolePlugin::readConfig()
 {
-    for (KateKonsolePluginView *view : qAsConst(mViews))
+    for (KateKonsolePluginView *view : qAsConst(mViews)) {
         view->readConfig();
+    }
 }
 
 KateKonsolePluginView::KateKonsolePluginView(KateKonsolePlugin *plugin, KTextEditor::MainWindow *mainWindow)
@@ -83,7 +96,11 @@ KateKonsolePluginView::KateKonsolePluginView(KateKonsolePlugin *plugin, KTextEdi
     , m_plugin(plugin)
 {
     // init console
-    QWidget *toolview = mainWindow->createToolView(plugin, QStringLiteral("kate_private_plugin_katekonsoleplugin"), KTextEditor::MainWindow::Bottom, QIcon::fromTheme(QStringLiteral("utilities-terminal")), i18n("Terminal"));
+    QWidget *toolview = mainWindow->createToolView(plugin,
+                                                   QStringLiteral("kate_private_plugin_katekonsoleplugin"),
+                                                   KTextEditor::MainWindow::Bottom,
+                                                   QIcon::fromTheme(QStringLiteral("utilities-terminal")),
+                                                   i18n("Terminal"));
     m_console = new KateConsole(m_plugin, mainWindow, toolview);
 
     // register this view
@@ -142,9 +159,11 @@ KateConsole::KateConsole(KateKonsolePlugin *plugin, KTextEditor::MainWindow *mw,
     a = actionCollection()->addAction(QStringLiteral("katekonsole_tools_toggle_focus"));
     a->setIcon(QIcon::fromTheme(QStringLiteral("swap-panels")));
     a->setText(i18nc("@action", "&Focus Terminal"));
-    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_F4));
+    actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_F4));
     connect(a, &QAction::triggered, this, &KateConsole::slotToggleFocus);
 
+    connect(m_mw, &KTextEditor::MainWindow::unhandledShortcutOverride, this, &KateConsole::handleEsc);
+
     m_mw->guiFactory()->addClient(this);
 
     readConfig();
@@ -153,31 +172,37 @@ KateConsole::KateConsole(KateKonsolePlugin *plugin, KTextEditor::MainWindow *mw,
 KateConsole::~KateConsole()
 {
     m_mw->guiFactory()->removeClient(this);
-    if (m_part)
+    if (m_part) {
         disconnect(m_part, &KParts::ReadOnlyPart::destroyed, this, &KateConsole::slotDestroyed);
+    }
 }
 
 void KateConsole::loadConsoleIfNeeded()
 {
-    if (m_part)
+    if (m_part) {
         return;
+    }
 
-    if (!window() || !parentWidget())
+    if (!window() || !parentWidget()) {
         return;
-    if (!window() || !isVisibleTo(window()))
+    }
+    if (!window() || !isVisibleTo(window())) {
         return;
+    }
 
     /**
      * get konsole part factory
      */
     KPluginFactory *factory = KPluginLoader(QStringLiteral("konsolepart")).factory();
-    if (!factory)
+    if (!factory) {
         return;
+    }
 
     m_part = factory->create<KParts::ReadOnlyPart>(this, this);
 
-    if (!m_part)
+    if (!m_part) {
         return;
+    }
 
     layout()->addWidget(m_part->widget());
 
@@ -190,7 +215,9 @@ void KateConsole::loadConsoleIfNeeded()
     m_part->widget()->show();
 
     connect(m_part, &KParts::ReadOnlyPart::destroyed, this, &KateConsole::slotDestroyed);
-    connect(m_part, SIGNAL(overrideShortcut(QKeyEvent *, bool &)), this, SLOT(overrideShortcut(QKeyEvent *, bool &)));
+    // clang-format off
+    connect(m_part, SIGNAL(overrideShortcut(QKeyEvent*,bool&)), this, SLOT(overrideShortcut(QKeyEvent*,bool&)));
+    // clang-format on
     slotSync();
 }
 
@@ -216,19 +243,22 @@ void KateConsole::overrideShortcut(QKeyEvent *, bool &override)
 
 void KateConsole::showEvent(QShowEvent *)
 {
-    if (m_part)
+    if (m_part) {
         return;
+    }
 
     loadConsoleIfNeeded();
 }
 
 void KateConsole::cd(const QString &path)
 {
-    if (m_currentPath == path)
+    if (m_currentPath == path) {
         return;
+    }
 
-    if (!m_part)
+    if (!m_part) {
         return;
+    }
 
     m_currentPath = path;
     QString command = QLatin1String(" cd ") + KShell::quoteArg(m_currentPath) + QLatin1Char('\n');
@@ -254,39 +284,46 @@ void KateConsole::sendInput(const QString &text)
 {
     loadConsoleIfNeeded();
 
-    if (!m_part)
+    if (!m_part) {
         return;
+    }
 
     TerminalInterface *t = qobject_cast<TerminalInterface *>(m_part);
 
-    if (!t)
+    if (!t) {
         return;
+    }
 
     t->sendInput(text);
 }
 
 void KateConsole::slotPipeToConsole()
 {
-    if (KMessageBox::warningContinueCancel(m_mw->window(),
-                                           i18n("Do you really want to pipe the text to the console? This will execute any contained commands with your user rights."),
-                                           i18n("Pipe to Terminal?"),
-                                           KGuiItem(i18n("Pipe to Terminal")),
-                                           KStandardGuiItem::cancel(),
-                                           QStringLiteral("Pipe To Terminal Warning")) != KMessageBox::Continue)
+    if (KMessageBox::warningContinueCancel(
+            m_mw->window(),
+            i18n("Do you really want to pipe the text to the console? This will execute any contained commands with your user rights."),
+            i18n("Pipe to Terminal?"),
+            KGuiItem(i18n("Pipe to Terminal")),
+            KStandardGuiItem::cancel(),
+            QStringLiteral("Pipe To Terminal Warning"))
+        != KMessageBox::Continue) {
         return;
+    }
 
     KTextEditor::View *v = m_mw->activeView();
 
-    if (!v)
+    if (!v) {
         return;
+    }
 
-    if (v->selection())
+    if (v->selection()) {
         sendInput(v->selectionText());
-    else
+    } else {
         sendInput(v->document()->text());
+    }
 }
 
-void KateConsole::slotSync(KTextEditor::View *)
+void KateConsole::slotSync()
 {
     if (m_mw->activeView()) {
         QUrl u = m_mw->activeView()->document()->url();
@@ -299,12 +336,24 @@ void KateConsole::slotSync(KTextEditor::View *)
     }
 }
 
+void KateConsole::slotViewOrUrlChanged(KTextEditor::View *view)
+{
+    disconnect(m_urlChangedConnection);
+    if (view) {
+        KTextEditor::Document *doc = view->document();
+        m_urlChangedConnection = connect(doc, &KParts::ReadOnlyPart::urlChanged, this, &KateConsole::slotSync);
+    }
+
+    slotSync();
+}
+
 void KateConsole::slotManualSync()
 {
     m_currentPath.clear();
     slotSync();
-    if (!m_part || !m_part->widget()->isVisible())
+    if (!m_part || !m_part->widget()->isVisible()) {
         m_mw->showToolView(parentWidget());
+    }
 }
 
 void KateConsole::slotRun()
@@ -346,17 +395,17 @@ void KateConsole::slotRun()
             output_str += file_path.absoluteFilePath();
         }
 
-        if (KMessageBox::Continue !=
-            KMessageBox::warningContinueCancel(m_mw->window(),
-                                               i18n("Do you really want to Run the document ?\n"
-                                                    "This will execute the following command,\n"
-                                                    "with your user rights, in the terminal:\n"
-                                                    "'%1'",
-                                                    output_str),
-                                               i18n("Run in Terminal?"),
-                                               KGuiItem(i18n("Run")),
-                                               KStandardGuiItem::cancel(),
-                                               QStringLiteral("Konsole: Run in Terminal Warning"))) {
+        if (KMessageBox::Continue
+            != KMessageBox::warningContinueCancel(m_mw->window(),
+                                                  i18n("Do you really want to Run the document ?\n"
+                                                       "This will execute the following command,\n"
+                                                       "with your user rights, in the terminal:\n"
+                                                       "'%1'",
+                                                       output_str),
+                                                  i18n("Run in Terminal?"),
+                                                  KGuiItem(i18n("Run")),
+                                                  KStandardGuiItem::cancel(),
+                                                  QStringLiteral("Konsole: Run in Terminal Warning"))) {
             return;
         }
         // echo to terminal
@@ -385,34 +434,61 @@ void KateConsole::slotToggleFocus()
         return; // this shows and focuses the konsole
     }
 
-    if (!m_part)
+    if (!m_part) {
         return;
+    }
 
     if (m_part->widget()->hasFocus()) {
-        if (m_mw->activeView())
+        if (m_mw->activeView()) {
             m_mw->activeView()->setFocus();
+        }
         action->setText(i18n("Focus Terminal"));
     } else {
         // show the view if it is hidden
-        if (parentWidget()->isHidden())
+        if (parentWidget()->isHidden()) {
             m_mw->showToolView(parentWidget());
-        else // should focus the widget too!
+        } else { // should focus the widget too!
             m_part->widget()->setFocus(Qt::OtherFocusReason);
+        }
         action->setText(i18n("Defocus Terminal"));
     }
 }
 
 void KateConsole::readConfig()
 {
-    disconnect(m_mw, &KTextEditor::MainWindow::viewChanged, this, &KateConsole::slotSync);
+    disconnect(m_mw, &KTextEditor::MainWindow::viewChanged, this, &KateConsole::slotViewOrUrlChanged);
+    disconnect(m_urlChangedConnection);
+
     if (KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("AutoSyncronize", true)) {
-        connect(m_mw, &KTextEditor::MainWindow::viewChanged, this, &KateConsole::slotSync);
+        connect(m_mw, &KTextEditor::MainWindow::viewChanged, this, &KateConsole::slotViewOrUrlChanged);
     }
 
-    if (KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("SetEditor", false))
+    if (KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("SetEditor", false)) {
         qputenv("EDITOR", "kate -b");
-    else
-        qputenv("EDITOR", m_plugin->previousEditorEnv().data());
+    } else {
+        setEditorEnv(m_plugin->previousEditorEnv());
+    }
+}
+
+void KateConsole::handleEsc(QEvent *e)
+{
+    if (!KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyBehaviour", true)) {
+        return;
+    }
+
+    QStringList exceptList = KConfigGroup(KSharedConfig::openConfig(), "Konsole").readEntry("KonsoleEscKeyExceptions", s_escapeExceptions);
+
+    if (!m_mw || !m_part || !m_toolView || !e) {
+        return;
+    }
+
+    QKeyEvent *k = static_cast<QKeyEvent *>(e);
+    if (k->key() == Qt::Key_Escape && k->modifiers() == Qt::NoModifier) {
+        const auto app = qobject_cast<TerminalInterface *>(m_part)->foregroundProcessName();
+        if (m_toolView && m_toolView->isVisible() && !exceptList.contains(app)) {
+            m_mw->hideToolView(m_toolView);
+        }
+    }
 }
 
 KateKonsoleConfigPage::KateKonsoleConfigPage(QWidget *parent, KateKonsolePlugin *plugin)
@@ -460,12 +536,26 @@ KateKonsoleConfigPage::KateKonsoleConfigPage(QWidget *parent, KateKonsolePlugin
     QLabel *tmp = new QLabel(this);
     tmp->setText(i18n("Important: The document has to be closed to make the console application continue"));
     lo->addWidget(tmp);
+
+    cbSetEscHideKonsole = new QCheckBox(i18n("Hide Konsole on pressing 'Esc'"));
+    lo->addWidget(cbSetEscHideKonsole);
+    QLabel *hideKonsoleLabel =
+        new QLabel(i18n("This may cause issues with terminal apps that use Esc key, for e.g., vim. Add these apps in the input below (Comma separated list)"),
+                   this);
+    lo->addWidget(hideKonsoleLabel);
+
+    leEscExceptions = new QLineEdit(this);
+    lo->addWidget(leEscExceptions);
+
     reset();
     lo->addStretch();
+
     connect(cbAutoSyncronize, &QCheckBox::stateChanged, this, &KateKonsoleConfigPage::changed);
     connect(cbRemoveExtension, &QCheckBox::stateChanged, this, &KTextEditor::ConfigPage::changed);
     connect(lePrefix, &QLineEdit::textChanged, this, &KateKonsoleConfigPage::changed);
     connect(cbSetEditor, &QCheckBox::stateChanged, this, &KateKonsoleConfigPage::changed);
+    connect(cbSetEscHideKonsole, &QCheckBox::stateChanged, this, &KateKonsoleConfigPage::changed);
+    connect(leEscExceptions, &QLineEdit::textChanged, this, &KateKonsoleConfigPage::changed);
 }
 
 void KateKonsoleConfigPage::slotEnableRunWarning()
@@ -495,6 +585,8 @@ void KateKonsoleConfigPage::apply()
     config.writeEntry("RemoveExtension", cbRemoveExtension->isChecked());
     config.writeEntry("RunPrefix", lePrefix->text());
     config.writeEntry("SetEditor", cbSetEditor->isChecked());
+    config.writeEntry("KonsoleEscKeyBehaviour", cbSetEscHideKonsole->isChecked());
+    config.writeEntry("KonsoleEscKeyExceptions", leEscExceptions->text().split(QLatin1Char(',')));
     config.sync();
     mPlugin->readConfig();
 }
@@ -506,8 +598,10 @@ void KateKonsoleConfigPage::reset()
     cbRemoveExtension->setChecked(config.readEntry("RemoveExtension", false));
     lePrefix->setText(config.readEntry("RunPrefix", ""));
     cbSetEditor->setChecked(config.readEntry("SetEditor", false));
+    cbSetEscHideKonsole->setChecked(config.readEntry("KonsoleEscKeyBehaviour", true));
+    leEscExceptions->setText(config.readEntry("KonsoleEscKeyExceptions", s_escapeExceptions).join(QLatin1Char(',')));
 }
 
 #include "kateconsole.moc"
 
-// kate: space-indent on; indent-width 2; replace-tabs on;
+// kate: space-indent on; indent-width 4; replace-tabs on;
