@@ -262,7 +262,14 @@ void GitWidget::setDotGitPath()
     git.start(QProcess::ReadOnly);
     if (git.waitForStarted() && git.waitForFinished(-1)) {
         if (git.exitStatus() != QProcess::NormalExit || git.exitCode() != 0) {
-            sendMessage(i18n("Failed to find .git directory, things may not work correctly: %1", QString::fromUtf8(git.readAllStandardError())), true);
+            const QString error = QString::fromUtf8(git.readAllStandardError());
+
+            /**
+             * Do this on next even loop iteration because we may be in the constructor of pluginView
+             */
+            QTimer::singleShot(1, this, [this, error] {
+                sendMessage(i18n("Failed to find .git directory, things may not work correctly: %1", error), false);
+            });
             m_gitPath = m_project->baseDir();
             return;
         }
@@ -299,8 +306,9 @@ QProcess *GitWidget::gitp()
     auto git = new QProcess(this);
     git->setProgram(QStringLiteral("git"));
     git->setWorkingDirectory(m_gitPath);
-    connect(git, &QProcess::errorOccurred, this, [this, git](QProcess::ProcessError) {
-        sendMessage(git->errorString(), true);
+    connect(git, &QProcess::errorOccurred, this, [this, git](QProcess::ProcessError pe) {
+        // git program missing is not an error
+        sendMessage(git->errorString(), pe != QProcess::FailedToStart);
         git->deleteLater();
     });
     return git;
@@ -634,6 +642,7 @@ void GitWidget::opencommitChangesDialog()
     GitCommitDialog *dialog = new GitCommitDialog(m_commitMessage, font, this);
 
     connect(dialog, &QDialog::finished, this, [this, dialog](int res) {
+        dialog->deleteLater();
         if (res == QDialog::Accepted) {
             if (dialog->subject().isEmpty()) {
                 return sendMessage(i18n("Commit message cannot be empty."), true);
@@ -641,7 +650,6 @@ void GitWidget::opencommitChangesDialog()
             m_commitMessage = dialog->subject() + QStringLiteral("[[\n\n]]") + dialog->description();
             commitChanges(dialog->subject(), dialog->description(), dialog->signoff());
         }
-        dialog->deleteLater();
     });
 
     dialog->open();
