@@ -72,26 +72,14 @@ KateProjectView::KateProjectView(KateProjectPluginView *pluginView, KateProject
     /**
      * Setup git checkout stuff
      */
-    m_branchBtn->setHidden(true);
     connect(m_branchBtn, &QPushButton::clicked, this, [this, mainWindow] {
         BranchCheckoutDialog bd(mainWindow->window(), m_pluginView, m_project->baseDir());
         bd.openDialog();
     });
 
-    connect(m_project, &KateProject::modelChanged, this, [this] {
-        if (GitUtils::isGitRepo(m_project->baseDir())) {
-            m_branchBtn->setHidden(false);
-            m_branchBtn->setText(GitUtils::getCurrentBranchName(m_project->baseDir()));
-            if (m_branchChangedWatcher.files().isEmpty()) {
-                m_branchChangedWatcher.addPath(m_project->baseDir() + QStringLiteral("/.git/HEAD"));
-            }
-        } else {
-            if (!m_branchChangedWatcher.files().isEmpty()) {
-                m_branchChangedWatcher.removePaths(m_branchChangedWatcher.files());
-            }
-            m_branchBtn->setHidden(true);
-        }
-    });
+    checkAndRefreshGit();
+
+    connect(m_project, &KateProject::modelChanged, this, &KateProjectView::checkAndRefreshGit);
     connect(&m_branchChangedWatcher, &QFileSystemWatcher::fileChanged, this, [this] {
         m_project->reload(true);
     });
@@ -159,3 +147,23 @@ void KateProjectView::showFileGitHistory(const QString &file)
     m_stackWidget->addWidget(fhs);
     m_stackWidget->setCurrentWidget(fhs);
 }
+
+void KateProjectView::checkAndRefreshGit()
+{
+    const auto dotGitPath = GitUtils::getDotGitPath(m_project->baseDir());
+    /**
+     * Not in a git repo or git was removed
+     */
+    if (dotGitPath.isEmpty()) {
+        if (!m_branchChangedWatcher.files().isEmpty()) {
+            m_branchChangedWatcher.removePaths(m_branchChangedWatcher.files());
+        }
+        m_branchBtn->setHidden(true);
+    } else {
+        m_branchBtn->setHidden(false);
+        m_branchBtn->setText(GitUtils::getCurrentBranchName(dotGitPath));
+        if (m_branchChangedWatcher.files().isEmpty()) {
+            m_branchChangedWatcher.addPath(dotGitPath + QStringLiteral(".git/HEAD"));
+        }
+    }
+}
