@@ -16,7 +16,6 @@
 #include <KSharedConfig>
 #include <KStartupInfo>
 #include <KWindowInfo>
-#include <kwindowsystem_version.h>
 
 #ifdef WITH_KUSERFEEDBACK
 #include <KUserFeedback/ApplicationVersionSource>
@@ -29,11 +28,16 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QDBusConnection>
 #include <QFileInfo>
 #include <QFileOpenEvent>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QLoggingCategory>
 #include <QTextCodec>
+#include <QUrlQuery>
 
-#include "../../urlinfo.h"
+#include <urlinfo.h>
 
 /**
  * singleton instance pointer
@@ -49,6 +53,7 @@ KateApp::KateApp(const QCommandLineParser &args)
     , m_adaptor(this)
     , m_pluginManager(this)
     , m_sessionManager(this)
+    , m_stashManager(this)
 {
     /**
      * re-route some signals to application wrapper
@@ -56,8 +61,6 @@ KateApp::KateApp(const QCommandLineParser &args)
     connect(&m_docManager, &KateDocManager::documentCreated, &m_wrapper, &KTextEditor::Application::documentCreated);
     connect(&m_docManager, &KateDocManager::documentWillBeDeleted, &m_wrapper, &KTextEditor::Application::documentWillBeDeleted);
     connect(&m_docManager, &KateDocManager::documentDeleted, &m_wrapper, &KTextEditor::Application::documentDeleted);
-    connect(&m_docManager, &KateDocManager::aboutToCreateDocuments, &m_wrapper, &KTextEditor::Application::aboutToCreateDocuments);
-    connect(&m_docManager, &KateDocManager::documentsCreated, &m_wrapper, &KTextEditor::Application::documentsCreated);
 
     /**
      * handle mac os x like file open request via event filter
@@ -186,12 +189,8 @@ bool KateApp::startupKate()
 
     // notify about start
     QWidget *win = activeKateMainWindow();
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 62, 0)
     win->setAttribute(Qt::WA_NativeWindow, true);
     KStartupInfo::setNewStartupId(win->windowHandle(), KStartupInfo::startupId());
-#else
-    KStartupInfo::setNewStartupId(win, KStartupInfo::startupId());
-#endif
 
     QTextCodec *codec = m_args.isSet(QStringLiteral("encoding")) ? QTextCodec::codecForName(m_args.value(QStringLiteral("encoding")).toUtf8()) : nullptr;
     bool tempfileSet = m_args.isSet(QStringLiteral("tempfile"));
@@ -199,10 +198,7 @@ bool KateApp::startupKate()
     KTextEditor::Document *doc = nullptr;
     const QString codec_name = codec ? QString::fromLatin1(codec->name()) : QString();
 
-    //  Bug 397913: Reverse the order here so the new tabs are opened in same order as the files were passed in on the command line
-    QString positionalArgument;
-    for (int i = m_args.positionalArguments().count() - 1; i >= 0; --i) {
-        positionalArgument = m_args.positionalArguments().at(i);
+    for (const auto &positionalArgument : m_args.positionalArguments()) {
         UrlInfo info(positionalArgument);
 
         // this file is no local dir, open it, else warn
@@ -212,23 +208,11 @@ bool KateApp::startupKate()
             doc = openDocUrl(info.url, codec_name, tempfileSet);
             if (info.cursor.isValid()) {
                 setCursor(info.cursor.line(), info.cursor.column());
-            } else if (info.url.hasQuery()) {
-                QUrlQuery q(info.url);
-                QString lineStr = q.queryItemValue(QStringLiteral("line"));
-                QString columnStr = q.queryItemValue(QStringLiteral("column"));
-
-                int line = lineStr.toInt();
-                if (line > 0)
-                    line--;
-
-                int column = columnStr.toInt();
-                if (column > 0)
-                    column--;
-
-                setCursor(line, column);
+            } else if (hasCursorInArgs()) {
+                setCursorFromArgs(activeMainWindow()->activeView());
             }
-        } else {
-            KMessageBox::sorry(activeKateMainWindow(), i18n("The file '%1' could not be opened: it is not a normal file, it is a folder.", info.url.toString()));
+        } else if (!KateApp::self()->pluginManager()->plugin(QStringLiteral("kateprojectplugin"))) {
+            KMessageBox::sorry(activeKateMainWindow(), i18n("Folders can only be opened when the projects plugin is enabled"));
         }
     }
 
@@ -254,26 +238,6 @@ bool KateApp::startupKate()
         activeKateMainWindow()->viewManager()->activateView(doc);
     }
 
-    int line = 0;
-    int column = 0;
-    bool nav = false;
-
-    if (m_args.isSet(QStringLiteral("line"))) {
-        line = m_args.value(QStringLiteral("line")).toInt() - 1;
-        nav = true;
-    }
-
-    if (m_args.isSet(QStringLiteral("column"))) {
-        column = m_args.value(QStringLiteral("column")).toInt() - 1;
-        nav = true;
-    }
-
-    if (nav && activeKateMainWindow()->viewManager()->activeView()) {
-        activeKateMainWindow()->viewManager()->activeView()->setCursorPosition(KTextEditor::Cursor(line, column));
-    }
-
-    activeKateMainWindow()->setAutoSaveSettings();
-
     return true;
 }
 
@@ -308,6 +272,11 @@ KateSessionManager *KateApp::sessionManager()
     return &m_sessionManager;
 }
 
+KateStashManager *KateApp::stashManager()
+{
+    return &m_stashManager;
+}
+
 bool KateApp::openUrl(const QUrl &url, const QString &encoding, bool isTempFile)
 {
     return openDocUrl(url, encoding, isTempFile);
@@ -319,8 +288,9 @@ bool KateApp::isOnActivity(const QString &activity)
         const KWindowInfo info(window->winId(), {}, NET::WM2Activities);
         const auto activities = info.activities();
         // handle special case of "on all activities"
-        if (activities.isEmpty() || activities.contains(activity))
+        if (activities.isEmpty() || activities.contains(activity)) {
             return true;
+        }
     }
 
     return false;
@@ -342,18 +312,79 @@ KTextEditor::Document *KateApp::openDocUrl(const QUrl &url, const QString &encod
     KTextEditor::Document *doc = nullptr;
 
     if (noDir) {
+        KateDocumentInfo docInfo;
+        docInfo.doPostLoadOperations = !url.isLocalFile() && (hasCursorInArgs() || url.hasQuery());
         // open a normal file
         if (codec) {
-            doc = mainWindow->viewManager()->openUrl(url, QString::fromLatin1(codec->name()), true, isTempFile);
+            doc = mainWindow->viewManager()->openUrl(url, QString::fromLatin1(codec->name()), true, isTempFile, docInfo);
         } else {
-            doc = mainWindow->viewManager()->openUrl(url, QString(), true, isTempFile);
+            doc = mainWindow->viewManager()->openUrl(url, QString(), true, isTempFile, docInfo);
         }
-    } else
+    } else {
         KMessageBox::sorry(mainWindow, i18n("The file '%1' could not be opened: it is not a normal file, it is a folder.", url.url()));
+    }
 
     return doc;
 }
 
+void KateApp::setCursorFromArgs(KTextEditor::View *view)
+{
+    int line = 0;
+    int column = 0;
+    bool nav = false;
+
+    if (!view && !(view = activeKateMainWindow()->activeView())) {
+        return;
+    }
+
+    if (m_args.isSet(QStringLiteral("line"))) {
+        line = m_args.value(QStringLiteral("line")).toInt() - 1;
+        nav = true;
+    }
+
+    if (m_args.isSet(QStringLiteral("column"))) {
+        column = m_args.value(QStringLiteral("column")).toInt() - 1;
+        nav = true;
+    }
+
+    if (nav) {
+        view->setCursorPosition(KTextEditor::Cursor(line, column));
+        activeKateMainWindow()->setAutoSaveSettings();
+    }
+}
+
+void KateApp::setCursorFromQueryString(KTextEditor::View *view)
+{
+    int line = 0;
+    int column = 0;
+    bool nav = false;
+
+    if (!view && !(view = activeKateMainWindow()->activeView())) {
+        return;
+    }
+
+    QUrlQuery urlQuery(view->document()->url());
+    QString lineStr = urlQuery.queryItemValue(QStringLiteral("line"));
+    QString columnStr = urlQuery.queryItemValue(QStringLiteral("column"));
+
+    if (!lineStr.isEmpty()) {
+        line = lineStr.toInt();
+        line > 0 && line--;
+        nav = true;
+    }
+
+    if (!columnStr.isEmpty()) {
+        column = columnStr.toInt();
+        column > 0 && column--;
+        nav = true;
+    }
+
+    if (nav) {
+        view->setCursorPosition(KTextEditor::Cursor(line, column));
+        activeKateMainWindow()->setAutoSaveSettings();
+    }
+}
+
 bool KateApp::setCursor(int line, int column)
 {
     KateMainWindow *mainWindow = activeKateMainWindow();
@@ -370,6 +401,11 @@ bool KateApp::setCursor(int line, int column)
     return true;
 }
 
+bool KateApp::hasCursorInArgs()
+{
+    return m_args.isSet(QStringLiteral("line")) || m_args.isSet(QStringLiteral("column"));
+}
+
 bool KateApp::openInput(const QString &text, const QString &encoding)
 {
     activeKateMainWindow()->viewManager()->openUrl(QUrl(), encoding, true);
@@ -482,8 +518,9 @@ void KateApp::remoteMessageReceived(const QString &message, QObject *)
      * try to parse message, ignore if no object
      */
     const QJsonDocument jsonMessage = QJsonDocument::fromJson(message.toUtf8());
-    if (!jsonMessage.isObject())
+    if (!jsonMessage.isObject()) {
         return;
+    }
 
     /**
      * open all passed urls
