@@ -15,7 +15,6 @@
 
 #include <KStartupInfo>
 #include <KWindowSystem>
-#include <kwindowsystem_version.h>
 
 #include <QApplication>
 
@@ -42,12 +41,8 @@ void KateAppAdaptor::activate()
     win->activateWindow();
 
     // try to raise window, see bug 407288
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 62, 0)
     win->setAttribute(Qt::WA_NativeWindow, true);
     KStartupInfo::setNewStartupId(win->windowHandle(), KStartupInfo::startupId());
-#else
-    KStartupInfo::setNewStartupId(win, KStartupInfo::startupId());
-#endif
     KWindowSystem::activateWindow(win->effectiveWinId());
 }
 
@@ -128,7 +123,7 @@ QString KateAppAdaptor::activeSession()
 
 void KateAppAdaptor::emitExiting()
 {
-    emit exiting();
+    Q_EMIT exiting();
 }
 
 void KateAppAdaptor::emitDocumentClosed(const QString &token)
