@@ -18,7 +18,6 @@
 #include "katesessionmanager.h"
 #include "kateviewmanager.h"
 
-
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -82,52 +81,30 @@ void KateConfigDialog::addBehaviorPage()
     QVBoxLayout *vbox = new QVBoxLayout;
     layout->addWidget(buttonGroup);
 
+    auto hlayout = new QHBoxLayout;
+    auto label = new QLabel(i18n("&Switch to output view upon message type:"), buttonGroup);
+    hlayout->addWidget(label);
+    m_messageTypes = new QComboBox(buttonGroup);
+    hlayout->addWidget(m_messageTypes);
+    label->setBuddy(m_messageTypes);
+    m_messageTypes->addItems({i18n("Never"), i18n("Error"), i18n("Warning"), i18n("Info"), i18n("Log")});
+    m_messageTypes->setCurrentIndex(cgGeneral.readEntry("Show output view for message type", 1));
+    connect(m_messageTypes, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &KateConfigDialog::slotChanged);
+    vbox->addLayout(hlayout);
+
     // modified files notification
-    m_modNotifications = new QCheckBox(i18n("Wa&rn about files modified by foreign processes"), buttonGroup);
+    m_modNotifications = new QCheckBox(i18n("Use a separate &dialog for handling externally modified files"), buttonGroup);
     m_modNotifications->setChecked(m_mainWindow->modNotificationEnabled());
     m_modNotifications->setWhatsThis(
-        i18n("If enabled, when Kate receives focus you will be asked what to do with "
-             "files that have been modified on the hard disk. If not enabled, you will "
-             "be asked what to do with a file that has been modified on the hard disk only "
-             "when that file is tried to be saved."));
+        i18n("If enabled, a modal dialog will be used to show all of the modified files. "
+             "If not enabled, you will be individually asked what to do for each modified file "
+             "only when that file's view receives focus."));
     connect(m_modNotifications, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
 
     vbox->addWidget(m_modNotifications);
 
     buttonGroup->setLayout(vbox);
 
-    // quick search
-    buttonGroup = new QGroupBox(i18n("&Quick Open"), generalFrame);
-    vbox = new QVBoxLayout;
-    buttonGroup->setLayout(vbox);
-    // quick open match mode
-    auto hlayout = new QHBoxLayout;
-    auto label = new QLabel(i18n("&Match Mode:"), buttonGroup);
-    hlayout->addWidget(label);
-    m_cmbQuickOpenMatchMode = new QComboBox(buttonGroup);
-    hlayout->addWidget(m_cmbQuickOpenMatchMode);
-    label->setBuddy(m_cmbQuickOpenMatchMode);
-    m_cmbQuickOpenMatchMode->addItem(i18n("Filename"), QVariant(KateQuickOpenModel::Columns::FileName));
-    m_cmbQuickOpenMatchMode->addItem(i18n("Filepath"), QVariant(KateQuickOpenModel::Columns::FilePath));
-    m_cmbQuickOpenMatchMode->setCurrentIndex(m_cmbQuickOpenMatchMode->findData(m_mainWindow->quickOpenMatchMode()));
-    m_mainWindow->setQuickOpenMatchMode(m_cmbQuickOpenMatchMode->currentData().toInt());
-    connect(m_cmbQuickOpenMatchMode, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &KateConfigDialog::slotChanged);
-    vbox->addLayout(hlayout);
-    // quick open list mode
-    hlayout = new QHBoxLayout;
-    label = new QLabel(i18n("&List Mode:"), buttonGroup);
-    hlayout->addWidget(label);
-    m_cmbQuickOpenListMode = new QComboBox(buttonGroup);
-    hlayout->addWidget(m_cmbQuickOpenListMode);
-    label->setBuddy(m_cmbQuickOpenListMode);
-    m_cmbQuickOpenListMode->addItem(i18n("Current Project Files"), QVariant(KateQuickOpenModel::List::CurrentProject));
-    m_cmbQuickOpenListMode->addItem(i18n("All Projects Files"), QVariant(KateQuickOpenModel::List::AllProjects));
-    m_cmbQuickOpenListMode->setCurrentIndex(m_cmbQuickOpenListMode->findData(m_mainWindow->quickOpenListMode()));
-    m_mainWindow->setQuickOpenListMode(static_cast<KateQuickOpenModel::List>(m_cmbQuickOpenListMode->currentData().toInt()));
-    connect(m_cmbQuickOpenListMode, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &KateConfigDialog::slotChanged);
-    vbox->addLayout(hlayout);
-    layout->addWidget(buttonGroup);
-
     // tabbar => we allow to configure some limit on number of tabs to show
     buttonGroup = new QGroupBox(i18n("&Tabs"), generalFrame);
     vbox = new QVBoxLayout;
@@ -156,6 +133,18 @@ void KateConfigDialog::addBehaviorPage()
     connect(m_expandTabs, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
     vbox->addWidget(m_expandTabs);
 
+    m_tabDoubleClickNewDocument = new QCheckBox(i18n("&Double click opens a new document"), buttonGroup);
+    m_tabDoubleClickNewDocument->setChecked(cgGeneral.readEntry("Tab Double Click New Document", true));
+    m_tabDoubleClickNewDocument->setToolTip(i18n("When checked double click opens a new document."));
+    connect(m_tabDoubleClickNewDocument, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
+    vbox->addWidget(m_tabDoubleClickNewDocument);
+
+    m_tabMiddleClickCloseDocument = new QCheckBox(i18n("&Middle click closes a document"), buttonGroup);
+    m_tabMiddleClickCloseDocument->setChecked(cgGeneral.readEntry("Tab Middle Click Close Document", true));
+    m_tabMiddleClickCloseDocument->setToolTip(i18n("When checked middle click closes a document."));
+    connect(m_tabMiddleClickCloseDocument, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
+    vbox->addWidget(m_tabMiddleClickCloseDocument);
+
     layout->addWidget(buttonGroup);
 
     layout->addStretch(1); // :-] works correct without autoadd
@@ -182,7 +171,10 @@ void KateConfigDialog::addSessionPage()
     sessionConfigUi.daysMetaInfos->setSpecialValueText(i18nc("The special case of 'Delete unused meta-information after'", "(never)"));
     sessionConfigUi.daysMetaInfos->setSuffix(ki18ncp("The suffix of 'Delete unused meta-information after'", " day", " days"));
     sessionConfigUi.daysMetaInfos->setValue(KateApp::self()->documentManager()->getDaysMetaInfos());
-    connect(sessionConfigUi.daysMetaInfos, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &KateConfigDialog::slotChanged);
+    connect(sessionConfigUi.daysMetaInfos,
+            static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged),
+            this,
+            &KateConfigDialog::slotChanged);
 
     // restore view  config
     sessionConfigUi.restoreVC->setChecked(cgGeneral.readEntry("Restore Window Configuration", true));
@@ -192,12 +184,13 @@ void KateConfigDialog::addSessionPage()
     connect(sessionConfigUi.spinBoxRecentFilesCount, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KateConfigDialog::slotChanged);
 
     QString sesStart(cgGeneral.readEntry("Startup Session", "manual"));
-    if (sesStart == QLatin1String("new"))
+    if (sesStart == QLatin1String("new")) {
         sessionConfigUi.startNewSessionRadioButton->setChecked(true);
-    else if (sesStart == QLatin1String("last"))
+    } else if (sesStart == QLatin1String("last")) {
         sessionConfigUi.loadLastUserSessionRadioButton->setChecked(true);
-    else
+    } else {
         sessionConfigUi.manuallyChooseSessionRadioButton->setChecked(true);
+    }
 
     connect(sessionConfigUi.startNewSessionRadioButton, &QRadioButton::toggled, this, &KateConfigDialog::slotChanged);
     connect(sessionConfigUi.loadLastUserSessionRadioButton, &QRadioButton::toggled, this, &KateConfigDialog::slotChanged);
@@ -206,6 +199,12 @@ void KateConfigDialog::addSessionPage()
     // Closing last file closes Kate
     sessionConfigUi.modCloseAfterLast->setChecked(m_mainWindow->modCloseAfterLast());
     connect(sessionConfigUi.modCloseAfterLast, &QCheckBox::toggled, this, &KateConfigDialog::slotChanged);
+
+    // stash unsave changes
+    sessionConfigUi.stashNewUnsavedFiles->setChecked(KateApp::self()->stashManager()->stashNewUnsavedFiles());
+    sessionConfigUi.stashUnsavedFilesChanges->setChecked(KateApp::self()->stashManager()->stashUnsavedChanges());
+    connect(sessionConfigUi.stashNewUnsavedFiles, &QRadioButton::toggled, this, &KateConfigDialog::slotChanged);
+    connect(sessionConfigUi.stashUnsavedFilesChanges, &QRadioButton::toggled, this, &KateConfigDialog::slotChanged);
 }
 
 void KateConfigDialog::addPluginsPage()
@@ -348,11 +347,12 @@ void KateConfigDialog::slotApply()
         cg.writeEntry("Close After Last", sessionConfigUi.modCloseAfterLast->isChecked());
         m_mainWindow->setModCloseAfterLast(sessionConfigUi.modCloseAfterLast->isChecked());
 
-        cg.writeEntry("Quick Open Search Mode", m_cmbQuickOpenMatchMode->currentData().toInt());
-        m_mainWindow->setQuickOpenMatchMode(m_cmbQuickOpenMatchMode->currentData().toInt());
+        cg.readEntry("Show output view for message type", m_messageTypes->currentIndex());
 
-        cg.writeEntry("Quick Open List Mode", m_cmbQuickOpenListMode->currentData().toInt());
-        m_mainWindow->setQuickOpenListMode(static_cast<KateQuickOpenModel::List>(m_cmbQuickOpenListMode->currentData().toInt()));
+        cg.writeEntry("Stash unsaved file changes", sessionConfigUi.stashUnsavedFilesChanges->isChecked());
+        KateApp::self()->stashManager()->setStashUnsavedChanges(sessionConfigUi.stashUnsavedFilesChanges->isChecked());
+        cg.writeEntry("Stash new unsaved files", sessionConfigUi.stashNewUnsavedFiles->isChecked());
+        KateApp::self()->stashManager()->setStashNewUnsavedFiles(sessionConfigUi.stashNewUnsavedFiles->isChecked());
 
         cg.writeEntry("Tabbar Tab Limit", m_tabLimit->value());
 
@@ -360,12 +360,16 @@ void KateConfigDialog::slotApply()
 
         cg.writeEntry("Expand Tabs", m_expandTabs->isChecked());
 
+        cg.writeEntry("Tab Double Click New Document", m_tabDoubleClickNewDocument->isChecked());
+        cg.writeEntry("Tab Middle Click Close Document", m_tabMiddleClickCloseDocument->isChecked());
+
         // patch document modified warn state
         const QList<KTextEditor::Document *> &docs = KateApp::self()->documentManager()->documentList();
-        for (KTextEditor::Document *doc : docs)
+        for (KTextEditor::Document *doc : docs) {
             if (qobject_cast<KTextEditor::ModificationInterface *>(doc)) {
                 qobject_cast<KTextEditor::ModificationInterface *>(doc)->setModifiedOnDiskWarning(!m_modNotifications->isChecked());
             }
+        }
 
         m_mainWindow->saveOptions();
 
@@ -391,8 +395,9 @@ void KateConfigDialog::slotApply()
     }
 
     // apply ktexteditor pages
-    for (KTextEditor::ConfigPage *page : qAsConst(m_editorPages))
+    for (KTextEditor::ConfigPage *page : qAsConst(m_editorPages)) {
         page->apply();
+    }
 
     config->sync();
 
@@ -439,8 +444,12 @@ void KateConfigDialog::closeEvent(QCloseEvent *event)
         return;
     }
 
-    const auto response =
-        KMessageBox::warningYesNoCancel(this, i18n("You have unsaved changes. Do you want to apply the changes or discard them?"), i18n("Warning"), KStandardGuiItem::save(), KStandardGuiItem::discard(), KStandardGuiItem::cancel());
+    const auto response = KMessageBox::warningYesNoCancel(this,
+                                                          i18n("You have unsaved changes. Do you want to apply the changes or discard them?"),
+                                                          i18n("Warning"),
+                                                          KStandardGuiItem::save(),
+                                                          KStandardGuiItem::discard(),
+                                                          KStandardGuiItem::cancel());
     switch (response) {
     case KMessageBox::Yes:
         slotApply();
